// #autoload
// #name = Halsshot
// #version = 2.1
// #date = May 19, 2002
// #author = Halide
// #warrior = Halide
// #email = halide@popmail.com
// #web = http://halides.tribes-universe.com/
// #description = Takes screenshots without huds, waypoints, and reticles.
// #category = Halide's Scripts
// #config = HalsshotConfig

if(!isObject(Halsshot))
{
	new ScriptObject(Halsshot)
	{
		class = Halsshot;
		version = "2.1";
		// prefs
		saveDir = "Halsshot/";	// directory for screenshots (relative to base folder)
		saveName = "Halsshot";  // prefix file name
	};

	Halsshot.dir = new FileObject();
	Halsshot.dir.openForWrite(Halsshot.saveDir);
	Halsshot.dir.close();
	Halsshot.dir.delete();
}

function Halsshot(%val)
{
	if(playGui.isAwake() && %val)
		Halsshot.doScreenShot();
}

// START package Halsshot
package Halsshot
{

	function Halsshot::setPrefs(%this)
	{
		if(isFile("prefs/HalPrefs.cs") && !$HalPrefsLoaded)
		{
			exec("prefs/HalPrefs.cs");
			$HalPrefsLoaded = true;
		}

		if($HalPref::sshot::Version !$= Halsshot.version)
		{
			$HalPref::sshot::Version = Halsshot.version;
			$HalPref::sshot::HideItems = true;
			$HalPref::sshot::HidePlayer = true;
			$HalPref::sshot::Gamma = $AutoloadExecuted ? 0.125 : 0;
		}
	}

	function loadDemoSettings()
	{
		parent::loadDemoSettings();

		globalActionMap.copyBind(moveMap, Halsshot);
		
		Halsshot.device = getField(moveMap.getBinding(Halsshot), 0);
		Halsshot.action = getField(moveMap.getBinding(Halsshot), 1);
	}

	function demoPlaybackComplete()
	{
		parent::demoPlaybackComplete();

		globalActionMap.unbind(Halsshot.device, Halsshot.action);
	}

	function clientCmdSetDefaultVehicleKeys(%inVehicle)
	{
		parent::clientCmdSetDefaultVehicleKeys(%inVehicle);

		if(%inVehicle)
			passengerKeys.copyBind(moveMap, Halsshot);
	}

	function screenShot(%file)
	{
		HalsshotGammaAdjust.extent = canvas.getExtent();
		HalsshotGammaAdjust.opacity = $HalPref::sshot::Gamma;

		canvas.pushDialog(HalsshotGammaAdjust);

		canvas.hideCursor();
		canvas.repaint();

		parent::screenShot(%file);

		canvas.showCursor();

		canvas.popDialog(HalsshotGammaAdjust);
	}

	function Halsshot::doScreenShot(%this)
	{
		%this.hide(true);

		for(%found = true; %found; %this.count++ )
		{
			%suffix = %this.count @ ".";
			while(strlen(%suffix) < 5)
				%suffix = "0" @ %suffix;
			%fileName = %this.saveDir @ %this.saveName @ %suffix @ "png";
			%found = isFile(%fileName);
		}
		screenShot("base/" @ %fileName);

		echo("** Halsshot saved ** " @ %fileName);

		%this.hide(false);
	}

	function Halsshot::hide(%this, %val)
	{
		if(%val)
		{
			%this.renderMyItems = $pref::Player::renderMyItems;
			%this.renderMyPlayer = $pref::Player::renderMyPlayer;

			if($HalPref::sshot::HideItems)
				$pref::Player::renderMyItems = false;
			if($HalPref::sshot::HidePlayer)
				$pref::Player::renderMyPlayer = false;

			canvas.setContent(panoramaGui);

			panoramaGui.beaconsVisible = false;
		}
		else
		{

			$pref::Player::renderMyItems = %this.renderMyItems;
			$pref::Player::renderMyPlayer = %this.renderMyPlayer;

			canvas.setContent(playGui);
		}
	}

	function Halsshot::setup(%this)
	{
		if(%this.setup)
			return;

		%this.setPrefs();

		new GuiControl(HalsshotConfig) {
			profile = "GuiDefaultProfile";
			horizSizing = "center";
			vertSizing = "center";
			position = "0 0";
			extent = "640 480";
			minExtent = "8 8";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";

			new ShellPaneCtrl() {
				profile = "ShellPaneProfile";
				horizSizing = "center";
				vertSizing = "center";
				position = "220 169";
				extent = "199 142";
				minExtent = "48 92";
				visible = "1";
				hideCursor = "0";
				bypassHideCursor = "0";
				helpTag = "0";
				text = "Halsshot";
				longTextBuffer = "0";
				maxLength = "255";
				noTitleBar = "0";

				new GuiTextCtrl() {
					profile = "GuiDefaultProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "63 83";
					extent = "77 16";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "Gamma Adjust";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new ShellFieldCtrl() {
					profile = "ShellFieldProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "19 29";
					extent = "161 94";
					minExtent = "16 18";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
				};
				new GuiTextCtrl(HalsshotConfigGammaText) {
					profile = "GuiDefaultProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "89 98";
					extent = "34 16";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "50%";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new ShellSliderCtrl(HalsshotConfigGammaSlider) {
					profile = "ShellSliderProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "32 93";
					extent = "133 24";
					minExtent = "12 24";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					variable = "value";
					altCommand = "HalsshotConfig.updateInterval();";
					helpTag = "0";
					range = "0.000000 0.500000";
					ticks = "1000";
					value = "0.252252";
					usePlusMinus = "0";
				};
				new ShellToggleButton(HalsshotConfigHideItems) {
					profile = "ShellRadioProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "38 33";
					extent = "115 30";
					minExtent = "26 27";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					variable = "$HalPref::sshot::HideItems";
					helpTag = "0";
					text = "Hide items ";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new ShellToggleButton(HalsshotConfigHideItems) {
					profile = "ShellRadioProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "38 57";
					extent = "115 30";
					minExtent = "26 27";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					variable = "$HalPref::sshot::HidePlayer";
					helpTag = "0";
					text = "Hide player";
					longTextBuffer = "0";
					maxLength = "255";
				};
			};
		};

		HalsshotConfigGammaSlider.setValue($HalPref::sshot::Gamma);

		new HudBitmapCtrl(HalsshotGammaAdjust) {
			profile = "GuiDefaultProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "0 0";
			extent = "800 600";
			minExtent = "8 8";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			fillColor = "1.000000 1.000000 1.000000 1.000000";
			frameColor = "1.000000 1.000000 1.000000 1.000000";
			opacity = "0";
			autoCenter = "0";
			autoResize = "0";
			flipVertical = "0";
			flipHorizontal = "0";
		};

		%this.setup = true;
	}

	function HalsshotConfig::updateInterval(%this)
	{
		$HalPref::sshot::Gamma = (%gamma = HalsshotConfigGammaSlider.getValue());
		HalsshotConfigGammaText.setValue(mFormatFloat(%gamma / 0.5 * 100, "%.f") @ "%");
	}

	function DispatchLaunchMode()
	{
		parent::DispatchLaunchMode();

		Halsshot.setup();
	}

	function OptionsDlg::onWake(%this)
	{
		if(!Halsshot.bind)
		{
			$RemapName[$RemapCount] = "Halsshot - Screenshot";
			$RemapCmd[$RemapCount] = "Halsshot";
			$RemapCount++;

			Halsshot.bind = true;
		}

		parent::onWake(%this);
	}

// END package Halsshot
};
activatePackage(Halsshot);

if($AutoloadExecuted)
	Halsshot.setup();